# flodger 
A package for function-driven logging.

The ethos of `flodger` is to have all logging within a project driven by
function calls and function outputs.

No explicit log statements need inserting - just the addition of the `log_function_call`
decorator onto any and all functions that you want to log.
